//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import UIKit

class SampleError : Error {
    var msg : String?
    
    init(_ msg : String? = "Unknown" ) {
        self.msg = msg
    }
}

enum ApiResult {
    case Ready
    case Success
    case Fail
}

class SDKSampleBaseViewController: UIViewController {
    
    let tableView: UITableView = UITableView(frame: CGRect.zero, style: .plain)
    var safeArea: UILayoutGuide!

    var sections : [SectionOfRow]?
    
    init() {
        super.init(nibName: nil, bundle: nil)
    }
    
    required public init?(coder aDecoder: NSCoder) {
        fatalError("Never will happen")
    }
    
    override func loadView() {
        super.loadView()        
        self.safeArea = view.layoutMarginsGuide
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        if #available(iOS 15.0, *) {
            let navBarAppearance = UINavigationBarAppearance()
            navBarAppearance.configureWithOpaqueBackground()
            //Configure additional customizations here
            UINavigationBar.appearance().standardAppearance = navBarAppearance
            UINavigationBar.appearance().scrollEdgeAppearance = navBarAppearance
        }
    }
    
    func setupViews() {
        self.tableView.backgroundColor = .lightGray
        self.tableView.separatorStyle = UITableViewCell.SeparatorStyle.none
        self.view.addSubview(self.tableView)
        
        self.tableView.translatesAutoresizingMaskIntoConstraints = false
        self.tableView.topAnchor.constraint(equalTo: safeArea.topAnchor).isActive = true
        self.tableView.leftAnchor.constraint(equalTo: view.leftAnchor).isActive = true
        self.tableView.bottomAnchor.constraint(equalTo: safeArea.bottomAnchor).isActive = true
        self.tableView.rightAnchor.constraint(equalTo: view.rightAnchor).isActive = true
        
        if #available(iOS 15, *) {
            tableView.sectionHeaderTopPadding = 0
        }
    }
    
    func resetResultIndicator() {
        
        sections?.forEach({ (sectionRow) in
            sectionRow.items.forEach({ (row) in
                row.apiResult = .Ready
            })
        })
        
        self.tableView.reloadData()
    }
}
